#include <edapi/commander.h>

#include <edapi/util.h>

typedef struct {
    gchar *name;
    gchar *fid;
} EDCommanderPrivate;

struct _EDCommander {
    GObject parent;
};

struct _EDCommanderClass {
    GObjectClass parent_class;
};

G_DEFINE_TYPE_EXTENDED(
    EDCommander,
    ed_commander,
    G_TYPE_OBJECT,
    0,
    G_ADD_PRIVATE(EDCommander)
    );

static void ed_commander_dispose(GObject *obj)
{
    G_OBJECT_CLASS(ed_commander_parent_class)->dispose(obj);
}

static void ed_commander_finalize(GObject *obj)
{
    EDCommander *self = ED_COMMANDER(obj);
    EDCommanderPrivate *p = ed_commander_get_instance_private(self);

    g_free(p->name);
    p->name = NULL;

    g_free(p->fid);
    p->fid = NULL;

    G_OBJECT_CLASS(ed_commander_parent_class)->finalize(obj);
}

static void ed_commander_class_init(EDCommanderClass *klass)
{
    G_OBJECT_CLASS(klass)->dispose = ed_commander_dispose;
    G_OBJECT_CLASS(klass)->finalize = ed_commander_finalize;
}

static void ed_commander_init(EDCommander *self)
{
}

EDCommander *ed_commander_new(void)
{
    return g_object_new(ED_TYPE_COMMANDER, NULL);
}

EDCommander *ed_commander_new_from_entry(EDJournalEntry *entry)
{
    return_if_true(entry == NULL, NULL);

    if (!ed_journal_entry_is(entry, ED_JOURNAL_ENTRY_COMMANDER)) {
        return NULL;
    }

    gchar const *cmdr = NULL;
    gchar const *fid = NULL;

    cmdr = ed_journal_entry_get_string(entry, "Name");
    fid  = ed_journal_entry_get_string(entry, "FID");

    return_if_true(S_EMPTY(cmdr) || S_EMPTY(fid), NULL);

    EDCommander *self = ed_commander_new();
    return_if_true(self == NULL, NULL);

    EDCommanderPrivate *p = ed_commander_get_instance_private(self);

    p->name = g_strdup(cmdr);
    p->fid  = g_strdup(fid);

    return self;
}

gchar const *ed_commander_get_name(EDCommander *self)
{
    EDCommanderPrivate *p = ed_commander_get_instance_private(self);
    return p->name;
}

gchar const *ed_commander_get_fid(EDCommander *self)
{
    EDCommanderPrivate *p = ed_commander_get_instance_private(self);
    return p->fid;
}
